@@ -7,6 +7,7 @@
  */
 
 #include "messagedisplayhelper.h"
+#include "config-kalarm.h"
 #include "messagedisplayhelper_p.h"
 #include "messagedisplay.h"
 
@@ -25,7 +26,7 @@
 #include "screensaver.h" // DBUS-generated
 #include "kalarm_debug.h"
 
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
 
@@ -113,7 +114,7 @@ MessageDisplayHelper::MessageDisplayHelper(MessageDisplay* parent, const KAEvent
     {
         if (event.reminderMinutes() < 0)
         {
-            event.previousOccurrence(alarm.dateTime(false).effectiveKDateTime(), mDateTime, false);
+            event.previousOccurrence(alarm.dateTime(false).effectiveKDateTime(), mDateTime, KAEvent::Repeats::Ignore);
             if (!mDateTime.isValid()  &&  event.repeatAtLogin())
                 mDateTime = alarm.dateTime().addSecs(event.reminderMinutes() * 60);
         }
@@ -842,7 +843,7 @@ void MessageDisplayHelper::playAudio()
 */
 void MessageDisplayHelper::slotSpeak()
 {
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
     TextEditTextToSpeech::TextToSpeech* tts = TextEditTextToSpeech::TextToSpeech::self();
     if (!tts->isReady())
     {
@@ -850,9 +851,12 @@ void MessageDisplayHelper::slotSpeak()
         clearErrorMessage(ErrMsg_Speak);
         return;
     }
-
+#if HAVE_TEXTTOSPEECH_ENQUEUE_SUPPORT
+    tts->enqueue(mMessage);
+#else
     tts->say(mMessage);
 #endif
+#endif
 }
 
 /******************************************************************************
