@@ -33,7 +33,7 @@ namespace KAlarm
 * Parameters: parent:    parent widget for error message boxes
 *             alarmList: imported alarms are appended to this list
 */
-bool importCalendarFile(const QUrl& url, CalEvent::Types alarmTypes, bool newId, QWidget* parent, QHash<CalEvent::Type, QVector<KAEvent>>& alarmList)
+bool importCalendarFile(const QUrl& url, CalEvent::Types alarmTypes, bool newId, QWidget* parent, QHash<CalEvent::Type, QList<KAEvent>>& alarmList)
 {
     if (!url.isValid())
     {
